#! coding: utf-8
from django.db import models
from django.utils.translation import ugettext_lazy as _
from positions import PositionField
from easy_thumbnails.fields import ThumbnailerImageField

SLIDE_HTML_POSITION_CHOICES = (
    ('left-top', _('Top-Left'), ),
    ('left-mid', _('Middle-Left'), ),
    ('left-bot', _('Bottom-Left'), ),
    ('center-top', _('Top-Center'), ),
    ('center-mid', _('Middle-Center'), ),
    ('center-bot', _('Bottom-Center'), ),
    ('right-top', _('Top-Right'), ),
    ('right-mid', _('Middle-Right'), ),
    ('right-bot', _('Bottom-right'), ),
)


class Carrousel(models.Model):
    class Meta:
        verbose_name = _('carrousel')

    name = models.CharField(max_length=100, verbose_name=_('name'))
    slug = models.CharField(max_length=100, unique=True, verbose_name=_('slug'))
    interval = models.IntegerField(verbose_name=_('interval'))
    show_indicators = models.BooleanField(verbose_name=_('show indicators'), default=False)

    def __unicode__(self):
        return self.name


class Slide(models.Model):
    class Meta:
        verbose_name = _('slide')
        ordering = ['position', ]

    carrousel = models.ForeignKey(Carrousel, related_name='slides', verbose_name=_('carrousel'))

    name = models.CharField(max_length=100, verbose_name=_('name'))
    position = PositionField(verbose_name=_('position'))
    image = ThumbnailerImageField(upload_to='slider/', blank=True, null=True, verbose_name=_('image'))
    mobile_image = ThumbnailerImageField(upload_to='slider/', blank=True, null=True, verbose_name=_('mobile image'))
    html = models.TextField(blank=True, null=True, verbose_name=_('html'))
    html_position = models.CharField(max_length=30, blank=True, null=True, verbose_name=_('html position'),
                                     choices=SLIDE_HTML_POSITION_CHOICES)
    url = models.URLField(blank=True, null=True, verbose_name=_('url'))

    def __unicode__(self):
        return self.name



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-09-28 02:41
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import easy_thumbnails.fields
import positions.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Carrousel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='name')),
                ('slug', models.CharField(max_length=100, unique=True, verbose_name='slug')),
                ('interval', models.IntegerField(verbose_name='interval')),
                ('show_indicators', models.BooleanField(default=False, verbose_name='show indicators')),
            ],
            options={
                'verbose_name': 'carrousel',
            },
        ),
        migrations.CreateModel(
            name='Slide',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='name')),
                ('position', positions.fields.PositionField(default=-1, verbose_name='position')),
                ('image', easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to=b'slider/', verbose_name='image')),
                ('mobile_image', easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to=b'slider/', verbose_name='mobile image')),
                ('html', models.TextField(blank=True, null=True, verbose_name='html')),
                ('html_position', models.CharField(blank=True, choices=[(b'left-top', 'Top-Left'), (b'left-mid', 'Middle-Left'), (b'left-bot', 'Bottom-Left'), (b'center-top', 'Top-Center'), (b'center-mid', 'Middle-Center'), (b'center-bot', 'Bottom-Center'), (b'right-top', 'Top-Right'), (b'right-mid', 'Middle-Right'), (b'right-bot', 'Bottom-right')], max_length=30, null=True, verbose_name='html position')),
                ('url', models.URLField(blank=True, null=True, verbose_name='url')),
                ('carrousel', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='slides', to='carrousel.Carrousel', verbose_name='carrousel')),
            ],
            options={
                'ordering': ['position'],
                'verbose_name': 'slide',
            },
        ),
    ]



#! coding: utf-8
from django import template
from carrousel.models import Carrousel

register = template.Library()


@register.inclusion_tag('carrousel/carrousel.html')
def carousel(slug):
    try:
        current_carousel = Carrousel.objects.get(slug=slug)
        return {
            'carousel': current_carousel,
        }
    except Carrousel.DoesNotExist:
        pass



#! coding: utf-8
from setuptools import setup, find_packages
import os
import carrousel

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: Apache Software License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    "Programming Language :: Python :: 2.6",
    "Programming Language :: Python :: 2.7",
]


setup(
    author = u'Pablo García',
    author_email = 'poli@devartis.com',
    name = 'django-carrousel',
    version = carrousel.get_version(),
    description = 'A django application that allows adding carrousel with slides on your web site.',
    long_description = open(os.path.join(os.path.dirname(__file__), 'README.md')).read(),
    url = 'https://github.com/devartis/django-carrousel',
    packages = find_packages(),
    platforms = ['OS Independent'],
    license = 'Apache License',
    classifiers = CLASSIFIERS,
    install_requires = [
        'Django>=1.4',
	'south>=0.7.2',
        'django-positions>=0.5.2',
        'easy-thumbnails>=2.1',
    ],
    zip_safe = False,
)

